    	relevant:
    		"Emergency",
    		"exosuit",

    		#"suggestions",
    			# recommendations,

    		"vitals monitors",
    		"conditions monitors",
    		"body improvements",
    		"body mods",

    		"homeostasis",
    		"status",
    		"checks",
    		"CT scan",
    		"comprehensive",
    		"longevity",
    		"fertility",

    		"tests",
    		"Emergencys",

    		"guarantees",
    		"vows",
    		"oaths",
    		"assurances",
    		"insurances",
    		"ensurances",

    		"reliability",
    		"consistency",
    		"integrity",

    		"speed",
    		"calmness",

    		"education",

    		"augmentation",
    		"enhancement",
    		"improvements"